@@ -22,6 +22,8 @@ extern crate ndarray_linalg;
 extern crate ndarray_rand;
 extern crate ndarray_stats;
 extern crate statrs;
+#[cfg(feature="openblas-system")]
+extern crate blas_src;
 
 mod dist_util;
 pub mod distributions;
